summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit44af2b7aa26c61f2f059acc7a9726319cacaabcf (patch)
tree09c93f4a6fdef07c083e731d9f327850e83a6bf5
parentb8e1a56a901671dbd336c9bfd129dfb72a0cc41f (diff)
downloadkdirstat-44af2b7a.tar.gz
kdirstat-44af2b7a.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--kdirstat/kactivitytracker.cpp4
-rw-r--r--kdirstat/kactivitytracker.h2
-rw-r--r--kdirstat/kcleanup.cpp6
-rw-r--r--kdirstat/kcleanup.h8
-rw-r--r--kdirstat/kcleanupcollection.cpp2
-rw-r--r--kdirstat/kcleanupcollection.h2
-rw-r--r--kdirstat/kdirstatapp.cpp2
-rw-r--r--kdirstat/kdirstatapp.h4
-rw-r--r--kdirstat/kdirstatsettings.cpp42
-rw-r--r--kdirstat/kdirstatsettings.h24
-rw-r--r--kdirstat/kdirtree.cpp108
-rw-r--r--kdirstat/kdirtree.h34
-rw-r--r--kdirstat/kdirtreeiterators.cpp20
-rw-r--r--kdirstat/kdirtreeiterators.h16
-rw-r--r--kdirstat/kdirtreeview.cpp58
-rw-r--r--kdirstat/kdirtreeview.h16
-rw-r--r--kdirstat/kfeedback.cpp18
-rw-r--r--kdirstat/kfeedback.h14
-rw-r--r--kdirstat/kpacman.cpp4
-rw-r--r--kdirstat/kpacman.h2
-rw-r--r--kdirstat/kstdcleanup.cpp28
-rw-r--r--kdirstat/kstdcleanup.h14
-rw-r--r--kdirstat/ktreemaptile.cpp4
-rw-r--r--kdirstat/ktreemaptile.h12
-rw-r--r--kdirstat/ktreemapview.cpp10
-rw-r--r--kdirstat/ktreemapview.h10
26 files changed, 232 insertions, 232 deletions
diff --git a/kdirstat/kactivitytracker.cpp b/kdirstat/kactivitytracker.cpp
index e83868b..5ef31fe 100644
--- a/kdirstat/kactivitytracker.cpp
+++ b/kdirstat/kactivitytracker.cpp
@@ -15,10 +15,10 @@
#include "kactivitytracker.h"
-KActivityTracker::KActivityTracker( TQObject * tqparent,
+KActivityTracker::KActivityTracker( TQObject * parent,
const TQString & id,
long initialThreshold )
- : TQObject( tqparent )
+ : TQObject( parent )
{
_id = id;
diff --git a/kdirstat/kactivitytracker.h b/kdirstat/kactivitytracker.h
index dd0856e..3680313 100644
--- a/kdirstat/kactivitytracker.h
+++ b/kdirstat/kactivitytracker.h
@@ -40,7 +40,7 @@ public:
* the application's @ref KConfig object doesn't contain a corresponding
* entry yet.
**/
- KActivityTracker( TQObject * tqparent,
+ KActivityTracker( TQObject * parent,
const TQString & id,
long initialThreshold );
diff --git a/kdirstat/kcleanup.cpp b/kdirstat/kcleanup.cpp
index 506067c..fa38a46 100644
--- a/kdirstat/kcleanup.cpp
+++ b/kdirstat/kcleanup.cpp
@@ -31,11 +31,11 @@ using namespace KDirStat;
KCleanup::KCleanup( TQString id,
TQString command,
TQString title,
- KActionCollection * tqparent )
+ KActionCollection * parent )
: KAction( title,
0, // accel
- tqparent,
+ parent,
id )
, _id ( id )
@@ -209,7 +209,7 @@ KCleanup::execute( KFileInfo *item )
case refreshParent:
- tree->refresh( item->tqparent() );
+ tree->refresh( item->parent() );
break;
diff --git a/kdirstat/kcleanupcollection.cpp b/kdirstat/kcleanupcollection.cpp
index 8b10505..627b979 100644
--- a/kdirstat/kcleanupcollection.cpp
+++ b/kdirstat/kcleanupcollection.cpp
@@ -80,7 +80,7 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* limitations of the KCleanup copy constructor: It doesn't make a
* truly identical copy of the entire KCleanup object. Rather, it
* copies only the KCleanup members and leaves most of the KAction
- * members (the tqparent class) untouched.
+ * members (the parent class) untouched.
*
* The behaviour implemented here comes handy in the most common
* situation where this assignment operator is used:
diff --git a/kdirstat/kcleanupcollection.h b/kdirstat/kcleanupcollection.h
index 2ac4fb8..9f1de8c 100644
--- a/kdirstat/kcleanupcollection.h
+++ b/kdirstat/kcleanupcollection.h
@@ -58,7 +58,7 @@ namespace KDirStat
* using the XML UI description ('kdirstatui.rc' for KDirStat).
*
* All @ref KCleanup actions ever added to this collection will get
- * this as their tqparent.
+ * this as their parent.
**/
KCleanupCollection( KActionCollection * actionCollection = 0 );
diff --git a/kdirstat/kdirstatapp.cpp b/kdirstat/kdirstatapp.cpp
index 81fce60..5a91375 100644
--- a/kdirstat/kdirstatapp.cpp
+++ b/kdirstat/kdirstatapp.cpp
@@ -226,7 +226,7 @@ KDirStatApp::initActions()
_showTreemapView->setStatusText ( i18n( "Enables/disables the treemap view" ) );
_treemapZoomIn->setStatusText ( i18n( "Zoom treemap in" ) );
_treemapZoomOut->setStatusText ( i18n( "Zoom treemap out" ) );
- _treemapSelectParent->setStatusText ( i18n( "Select tqparent" ) );
+ _treemapSelectParent->setStatusText ( i18n( "Select parent" ) );
_treemapRebuild->setStatusText ( i18n( "Rebuild treemap to fit into available space" ) );
pref->setStatusText ( i18n( "Opens the preferences dialog" ) );
_reportMailToOwner->setStatusText ( i18n( "Sends a mail to the owner of the selected subtree" ) );
diff --git a/kdirstat/kdirtree.cpp b/kdirstat/kdirtree.cpp
index 06b2bfc..34da482 100644
--- a/kdirstat/kdirtree.cpp
+++ b/kdirstat/kdirtree.cpp
@@ -29,9 +29,9 @@ using namespace KDirStat;
KFileInfo::KFileInfo( KDirTree * tree,
- KDirInfo * tqparent,
+ KDirInfo * parent,
const char * name )
- : _parent( tqparent )
+ : _parent( parent )
, _next( 0 )
, _tree( tree )
{
@@ -50,8 +50,8 @@ KFileInfo::KFileInfo( KDirTree * tree,
KFileInfo::KFileInfo( const TQString & filenameWithoutPath,
struct stat * statInfo,
KDirTree * tree,
- KDirInfo * tqparent )
- : _parent( tqparent )
+ KDirInfo * parent )
+ : _parent( parent )
, _next( 0 )
, _tree( tree )
{
@@ -102,15 +102,15 @@ KFileInfo::KFileInfo( const TQString & filenameWithoutPath,
KFileInfo::KFileInfo( const KFileItem * fileItem,
KDirTree * tree,
- KDirInfo * tqparent )
- : _parent( tqparent )
+ KDirInfo * parent )
+ : _parent( parent )
, _next( 0 )
, _tree( tree )
{
CHECK_PTR( fileItem );
_isLocalFile = fileItem->isLocalFile();
- _name = tqparent ? fileItem->name() : fileItem->url().url();
+ _name = parent ? fileItem->name() : fileItem->url().url();
_device = 0;
_mode = fileItem->mode();
_links = 1;
@@ -151,7 +151,7 @@ KFileInfo::~KFileInfo()
/**
* The destructor should also take care about unlinking this object from
- * its tqparent's tqchildren list, but regrettably that just doesn't work: At
+ * its parent's tqchildren list, but regrettably that just doesn't work: At
* this point (within the destructor) parts of the object are already
* destroyed, e.g., the virtual table - virtual methods don't work any
* more. Thus, somebody from outside must call deletingChild() just prior
@@ -225,7 +225,7 @@ KFileInfo::urlPart( int targetLevel ) const
while ( level > targetLevel )
{
level--;
- item = item->tqparent();
+ item = item->parent();
}
return item->name();
@@ -236,12 +236,12 @@ int
KFileInfo::treeLevel() const
{
int level = 0;
- KFileInfo * tqparent = _parent;
+ KFileInfo * parent = _parent;
- while ( tqparent )
+ while ( parent )
{
level++;
- tqparent = tqparent->tqparent();
+ parent = parent->parent();
}
return level;
@@ -271,7 +271,7 @@ KFileInfo::isInSubtree( const KFileInfo *subtree ) const
if ( ancestor == subtree )
return true;
- ancestor = ancestor->tqparent();
+ ancestor = ancestor->parent();
}
return false;
@@ -343,9 +343,9 @@ KFileInfo::locate( TQString url, bool findDotEntries )
KDirInfo::KDirInfo( KDirTree * tree,
- KDirInfo * tqparent,
+ KDirInfo * parent,
bool asDotEntry )
- : KFileInfo( tree, tqparent )
+ : KFileInfo( tree, parent )
{
init();
@@ -366,11 +366,11 @@ KDirInfo::KDirInfo( KDirTree * tree,
KDirInfo::KDirInfo( const TQString & filenameWithoutPath,
struct stat * statInfo,
KDirTree * tree,
- KDirInfo * tqparent )
+ KDirInfo * parent )
: KFileInfo( filenameWithoutPath,
statInfo,
tree,
- tqparent )
+ parent )
{
init();
_dotEntry = new KDirInfo( tree, this, true );
@@ -379,10 +379,10 @@ KDirInfo::KDirInfo( const TQString & filenameWithoutPath,
KDirInfo::KDirInfo( const KFileItem * fileItem,
KDirTree * tree,
- KDirInfo * tqparent )
+ KDirInfo * parent )
: KFileInfo( fileItem,
tree,
- tqparent )
+ parent )
{
init();
_dotEntry = new KDirInfo( tree, this, true );
@@ -597,7 +597,7 @@ KDirInfo::insertChild( KFileInfo *newChild )
**/
newChild->setNext( _firstChild );
_firstChild = newChild;
- newChild->setParent( this ); // make sure the tqparent pointer is correct
+ newChild->setParent( this ); // make sure the parent pointer is correct
childAdded( newChild ); // update summaries
}
@@ -669,7 +669,7 @@ KDirInfo::deletingChild( KFileInfo *deletedChild )
if ( _parent )
_parent->deletingChild( deletedChild );
- if ( ! _beingDestroyed && deletedChild->tqparent() == this )
+ if ( ! _beingDestroyed && deletedChild->parent() == this )
{
/**
* Unlink the child from the tqchildren's list - but only if this doesn't
@@ -686,7 +686,7 @@ KDirInfo::deletingChild( KFileInfo *deletedChild )
void
KDirInfo::unlinkChild( KFileInfo *deletedChild )
{
- if ( deletedChild->tqparent() != this )
+ if ( deletedChild->parent() != this )
{
kdError() << deletedChild << " is not a child of " << this
<< " - cannot unlink from tqchildren list!" << endl;
@@ -773,7 +773,7 @@ KDirInfo::cleanupDotEntries()
if ( ! _dotEntry || _isDotEntry )
return;
- // Retqparent dot entry tqchildren if there are no subdirectories on this level
+ // Reparent dot entry tqchildren if there are no subdirectories on this level
if ( ! _firstChild )
{
@@ -953,25 +953,25 @@ KLocalDirReadJob::startReading()
KFileInfo *
KLocalDirReadJob::stat( const KURL & url,
KDirTree * tree,
- KDirInfo * tqparent )
+ KDirInfo * parent )
{
struct stat statInfo;
if ( lstat( url.path(), &statInfo ) == 0 ) // lstat() OK
{
- TQString name = tqparent ? url.filename() : url.path();
+ TQString name = parent ? url.filename() : url.path();
if ( S_ISDIR( statInfo.st_mode ) ) // directory?
{
- KDirInfo * dir = new KDirInfo( name, &statInfo, tree, tqparent );
+ KDirInfo * dir = new KDirInfo( name, &statInfo, tree, parent );
- if ( dir && tqparent && dir->device() != tqparent->device() )
+ if ( dir && parent && dir->device() != parent->device() )
dir->setMountPoint();
return dir;
}
else // no directory
- return new KFileInfo( name, &statInfo, tree, tqparent );
+ return new KFileInfo( name, &statInfo, tree, parent );
}
else // lstat() failed
return 0;
@@ -1043,7 +1043,7 @@ KAnyDirReadJob::entries ( KIO::Job * job,
KFileItem entry( *it,
url,
true, // determineMimeTypeOnDemand
- true ); // URL is tqparent directory
+ true ); // URL is parent directory
if ( entry.name() != "." &&
entry.name() != ".." )
@@ -1097,7 +1097,7 @@ KAnyDirReadJob::finished( KIO::Job * job )
KFileInfo *
KAnyDirReadJob::stat( const KURL & url,
KDirTree * tree,
- KDirInfo * tqparent )
+ KDirInfo * parent )
{
KIO::UDSEntry uds_entry;
@@ -1105,9 +1105,9 @@ KAnyDirReadJob::stat( const KURL & url,
{
KFileItem entry( uds_entry, url,
true, // determine MIME type on demand
- false ); // URL specifies tqparent directory
+ false ); // URL specifies parent directory
- return entry.isDir() ? new KDirInfo ( &entry, tree, tqparent ) : new KFileInfo( &entry, tree, tqparent );
+ return entry.isDir() ? new KDirInfo ( &entry, tree, parent ) : new KFileInfo( &entry, tree, parent );
}
else // remote stat() failed
return 0;
@@ -1134,7 +1134,7 @@ KAnyDirReadJob::owner( KURL url )
{
KFileItem entry( uds_entry, url,
true, // determine MIME type on demand
- false ); // URL specifies tqparent directory
+ false ); // URL specifies parent directory
return entry.user();
}
@@ -1276,7 +1276,7 @@ KDirTree::refresh( KFileInfo *subtree )
if ( ! _root )
return;
- if ( ! subtree || ! subtree->tqparent() ) // Refresh all (from root)
+ if ( ! subtree || ! subtree->parent() ) // Refresh all (from root)
{
startReading( fixedUrl( _root->url() ) );
}
@@ -1285,7 +1285,7 @@ KDirTree::refresh( KFileInfo *subtree )
// Save some values from the old subtree.
KURL url = subtree->url();
- KDirInfo * tqparent = subtree->tqparent();
+ KDirInfo * parent = subtree->parent();
// Select nothing if the current selection is to be deleted
@@ -1300,7 +1300,7 @@ KDirTree::refresh( KFileInfo *subtree )
// kdDebug() << "Deleting subtree " << subtree << endl;
/**
- * This may sound stupid, but the tqparent must be told to unlink its
+ * This may sound stupid, but the parent must be told to unlink its
* child from the tqchildren list. The child cannot simply do this by
* itself in its destructor since at this point important parts of the
* object may already be destroyed, e.g., the virtual table -
@@ -1308,7 +1308,7 @@ KDirTree::refresh( KFileInfo *subtree )
*
* I just found that out the hard way by several hours of debugging. ;-}
**/
- tqparent->deletingChild( subtree );
+ parent->deletingChild( subtree );
delete subtree;
emit childDeleted();
@@ -1316,7 +1316,7 @@ KDirTree::refresh( KFileInfo *subtree )
// Create new subtree root.
subtree = ( _readMethod == KDirReadLocal ) ?
- KLocalDirReadJob::stat( url, this, tqparent ) : KAnyDirReadJob::stat( url, this, tqparent );
+ KLocalDirReadJob::stat( url, this, parent ) : KAnyDirReadJob::stat( url, this, parent );
// kdDebug() << "New subtree: " << subtree << endl;
@@ -1324,7 +1324,7 @@ KDirTree::refresh( KFileInfo *subtree )
{
// Insert new subtree root into the tree hierarchy.
- tqparent->insertChild( subtree );
+ parent->insertChild( subtree );
childAddedNotify( subtree );
if ( subtree->isDir() )
@@ -1444,48 +1444,48 @@ void
KDirTree::deleteSubtree( KFileInfo *subtree )
{
// kdDebug() << "Deleting subtree " << subtree << endl;
- KDirInfo *tqparent = subtree->tqparent();
+ KDirInfo *parent = subtree->parent();
- if ( tqparent )
+ if ( parent )
{
- // Give the tqparent of the child to be deleted a chance to unlink the
+ // Give the parent of the child to be deleted a chance to unlink the
// child from its tqchildren list and take care of internal summary
// fields
- tqparent->deletingChild( subtree );
+ parent->deletingChild( subtree );
}
// Send notification to anybody interested (e.g., to attached views)
deletingChildNotify( subtree );
- if ( tqparent )
+ if ( parent )
{
- if ( tqparent->isDotEntry() && ! tqparent->hasChildren() )
+ if ( parent->isDotEntry() && ! parent->hasChildren() )
// This was the last child of a dot entry
{
// Get rid of that now empty and useless dot entry
- if ( tqparent->tqparent() )
+ if ( parent->parent() )
{
- if ( tqparent->tqparent()->isFinished() )
+ if ( parent->parent()->isFinished() )
{
- // kdDebug() << "Removing empty dot entry " << tqparent << endl;
+ // kdDebug() << "Removing empty dot entry " << parent << endl;
- deletingChildNotify( tqparent );
- tqparent->tqparent()->setDotEntry( 0 );
+ deletingChildNotify( parent );
+ parent->parent()->setDotEntry( 0 );
- delete tqparent;
+ delete parent;
}
}
- else // no tqparent - this should never happen (?)
+ else // no parent - this should never happen (?)
{
- kdError() << "Internal error: Killing dot entry without tqparent " << tqparent << endl;
+ kdError() << "Internal error: Killing dot entry without parent " << parent << endl;
// Better leave that dot entry alone - we shouldn't have come
// here in the first place. Who knows what will happen if this
// thing is deleted now?!
//
// Intentionally NOT calling:
- // delete tqparent;
+ // delete parent;
}
}
}
diff --git a/kdirstat/kdirtree.h b/kdirstat/kdirtree.h
index 0de058f..b00767e 100644
--- a/kdirstat/kdirtree.h
+++ b/kdirstat/kdirtree.h
@@ -106,7 +106,7 @@ namespace KDirStat
* Default constructor.
**/
KFileInfo( KDirTree * tree,
- KDirInfo * tqparent = 0,
+ KDirInfo * parent = 0,
const char * name = 0 );
/**
@@ -115,14 +115,14 @@ namespace KDirStat
KFileInfo( const TQString & filenameWithoutPath,
struct stat * statInfo,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
/**
* Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
**/
KFileInfo( const KFileItem * fileItem,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
/**
* Destructor.
@@ -337,13 +337,13 @@ namespace KDirStat
KDirTree * tree() const { return _tree; }
/**
- * Returns a pointer to this entry's tqparent entry or 0 if there is
+ * Returns a pointer to this entry's parent entry or 0 if there is
* none.
**/
- KDirInfo * tqparent() const { return _parent; }
+ KDirInfo * parent() const { return _parent; }
/**
- * Set the "tqparent" pointer.
+ * Set the "parent" pointer.
**/
void setParent( KDirInfo *newParent ) { _parent = newParent; }
@@ -572,9 +572,9 @@ namespace KDirStat
KFileSize _blocks; // 512 bytes blocks
time_t _mtime; // modification time
- KDirInfo * _parent; // pointer to the tqparent entry
+ KDirInfo * _parent; // pointer to the parent entry
KFileInfo * _next; // pointer to the next entry
- KDirTree * _tree; // pointer to the tqparent tree
+ KDirTree * _tree; // pointer to the parent tree
}; // class KFileInfo
@@ -592,13 +592,13 @@ namespace KDirStat
/**
* Default constructor.
*
- * If "asDotEntry" is set, this will be used as the tqparent's
- * "dot entry", i.e. the pseudo directory that holds all the tqparent's
+ * If "asDotEntry" is set, this will be used as the parent's
+ * "dot entry", i.e. the pseudo directory that holds all the parent's
* non-directory tqchildren. This is the only way to create a "dot
* entry"!
**/
KDirInfo( KDirTree * tree,
- KDirInfo * tqparent = 0,
+ KDirInfo * parent = 0,
bool asDotEntry = false );
/**
@@ -607,14 +607,14 @@ namespace KDirStat
KDirInfo( const TQString & filenameWithoutPath,
struct stat * statInfo,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
/**
* Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
**/
KDirInfo( const KFileItem * fileItem,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
/**
* Destructor.
@@ -849,7 +849,7 @@ namespace KDirStat
/**
* Clean up unneeded / undesired dot entries:
* Delete dot entries that don't have any tqchildren,
- * reparent dot entry tqchildren to the "real" (tqparent) directory if
+ * reparent dot entry tqchildren to the "real" (parent) directory if
* there are not subdirectory siblings at the level of the dot entry.
**/
void cleanupDotEntries();
@@ -897,7 +897,7 @@ namespace KDirStat
* KDirTree.
*
* For each entry automatically a @ref KFileInfo or @ref KDirInfo will be
- * created and added to the tqparent @ref KDirInfo. For each directory a new
+ * created and added to the parent @ref KDirInfo. For each directory a new
* @ref KDirReadJob will be created and added to the @ref KDirTree 's job
* queue.
*
@@ -1007,7 +1007,7 @@ namespace KDirStat
**/
static KFileInfo * stat( const KURL & url,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
protected:
DIR * _diskDir;
@@ -1058,7 +1058,7 @@ namespace KDirStat
**/
static KFileInfo * stat( const KURL & url,
KDirTree * tree,
- KDirInfo * tqparent = 0 );
+ KDirInfo * parent = 0 );
/**
* Obtain the owner of the URL specified.
diff --git a/kdirstat/kdirtreeiterators.cpp b/kdirstat/kdirtreeiterators.cpp
index ff43bd3..4508e8f 100644
--- a/kdirstat/kdirtreeiterators.cpp
+++ b/kdirstat/kdirtreeiterators.cpp
@@ -15,29 +15,29 @@
using namespace KDirStat;
-KFileInfoIterator::KFileInfoIterator( KFileInfo * tqparent,
+KFileInfoIterator::KFileInfoIterator( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy )
{
- init( tqparent,
+ init( parent,
dotEntryPolicy,
true ); // callNext
}
-KFileInfoIterator::KFileInfoIterator( KFileInfo * tqparent,
+KFileInfoIterator::KFileInfoIterator( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy,
bool callNext )
{
- init( tqparent, dotEntryPolicy, callNext );
+ init( parent, dotEntryPolicy, callNext );
}
void
-KFileInfoIterator::init( KFileInfo * tqparent,
+KFileInfoIterator::init( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy,
bool callNext )
{
- _parent = tqparent;
+ _parent = parent;
_policy = dotEntryPolicy;
_current = 0;
@@ -174,11 +174,11 @@ KFileInfoIterator::count()
-KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * tqparent,
+KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy,
KFileInfoSortOrder sortOrder,
bool ascending )
- : KFileInfoIterator( tqparent, dotEntryPolicy, false )
+ : KFileInfoIterator( parent, dotEntryPolicy, false )
{
_sortOrder = sortOrder;
_ascending = ascending;
@@ -316,11 +316,11 @@ KFileInfoSortedIterator::finished()
-KFileInfoSortedBySizeIterator::KFileInfoSortedBySizeIterator( KFileInfo * tqparent,
+KFileInfoSortedBySizeIterator::KFileInfoSortedBySizeIterator( KFileInfo * parent,
KFileSize minSize,
KDotEntryPolicy dotEntryPolicy,
bool ascending )
- : KFileInfoSortedIterator( tqparent, dotEntryPolicy, KSortByTotalSize, ascending )
+ : KFileInfoSortedIterator( parent, dotEntryPolicy, KSortByTotalSize, ascending )
, _minSize( minSize )
{
}
diff --git a/kdirstat/kdirtreeview.cpp b/kdirstat/kdirtreeview.cpp
index 3da92d0..a8f74df 100644
--- a/kdirstat/kdirtreeview.cpp
+++ b/kdirstat/kdirtreeview.cpp
@@ -33,8 +33,8 @@
using namespace KDirStat;
-KDirTreeView::KDirTreeView( TQWidget * tqparent )
- : KDirTreeViewParentClass( tqparent )
+KDirTreeView::KDirTreeView( TQWidget * parent )
+ : KDirTreeViewParentClass( parent )
{
_tree = 0;
_updateTimer = 0;
@@ -135,7 +135,7 @@ KDirTreeView::~KDirTreeView()
/*
* Don't delete _updateTimer here, it's already automatically deleted by TQt!
- * (Since it's derived from TQObject and has a TQObject tqparent).
+ * (Since it's derived from TQObject and has a TQObject parent).
*/
}
@@ -337,9 +337,9 @@ KDirTreeView::clear()
void
KDirTreeView::addChild( KFileInfo *newChild )
{
- if ( newChild->tqparent() )
+ if ( newChild->parent() )
{
- KDirTreeViewItem *cloneParent = locate( newChild->tqparent(),
+ KDirTreeViewItem *cloneParent = locate( newChild->parent(),
_doLazyClone, // lazy
true ); // doClone
@@ -355,12 +355,12 @@ KDirTreeView::addChild( KFileInfo *newChild )
{
if ( ! _doLazyClone )
{
- kdError() << k_funcinfo << "Can't find tqparent view item for "
+ kdError() << k_funcinfo << "Can't find parent view item for "
<< newChild << endl;
}
}
}
- else // No tqparent - top level item
+ else // No parent - top level item
{
// kdDebug() << "Immediately top level cloning " << newChild << endl;
new KDirTreeViewItem( this, newChild );
@@ -383,7 +383,7 @@ KDirTreeView::deleteChild( KFileInfo *child )
/**
* The selected item is about to be deleted. Select some other item
* so there is still something selected: Preferably the next item
- * or the tqparent if there is no next. This cannot be done from
+ * or the parent if there is no next. This cannot be done from
* outside because the order of items is not known to the outside;
* it might appear very random if the next item in the KFileInfo
* list would be selected. The order of that list is definitely
@@ -397,17 +397,17 @@ KDirTreeView::deleteChild( KFileInfo *child )
* next item so he can clean up many items in a row.
**/
- nextSelection = clone->next() ? clone->next() : clone->tqparent();
+ nextSelection = clone->next() ? clone->next() : clone->parent();
// kdDebug() << k_funcinfo << " Next selection: " << nextSelection << endl;
}
- KDirTreeViewItem *tqparent = clone->tqparent();
+ KDirTreeViewItem *parent = clone->parent();
delete clone;
- while ( tqparent )
+ while ( parent )
{
- tqparent->updateSummary();
- tqparent = tqparent->tqparent();
+ parent->updateSummary();
+ parent = parent->parent();
}
if ( nextSelection )
@@ -979,22 +979,22 @@ KDirTreeViewItem::KDirTreeViewItem( KDirTreeView * view,
KDirTreeViewItem::KDirTreeViewItem( KDirTreeView * view,
- KDirTreeViewItem * tqparent,
+ KDirTreeViewItem * parent,
KFileInfo * orig )
- : TQListViewItem( tqparent )
+ : TQListViewItem( parent )
{
- CHECK_PTR( tqparent );
- init( view, tqparent, orig );
+ CHECK_PTR( parent );
+ init( view, parent, orig );
}
void
KDirTreeViewItem::init( KDirTreeView * view,
- KDirTreeViewItem * tqparent,
+ KDirTreeViewItem * parent,
KFileInfo * orig )
{
_view = view;
- _parent = tqparent;
+ _parent = parent;
_orig = orig;
_percent = 0.0;
_pacMan = 0;
@@ -1082,7 +1082,7 @@ KDirTreeViewItem::init( KDirTreeView * view,
}
}
- if ( ! tqparent || tqparent->isOpen() )
+ if ( ! parent || parent->isOpen() )
{
setIcon();
}
@@ -1184,11 +1184,11 @@ KDirTreeViewItem::updateSummary()
// Calculate and display percentage
- if ( _orig->tqparent() && // only if there is a tqparent as calculation base
- _orig->tqparent()->pendingReadJobs() < 1 && // not before subtree is finished reading
- _orig->tqparent()->totalSize() > 0 ) // avoid division by zero
+ if ( _orig->parent() && // only if there is a parent as calculation base
+ _orig->parent()->pendingReadJobs() < 1 && // not before subtree is finished reading
+ _orig->parent()->totalSize() > 0 ) // avoid division by zero
{
- _percent = ( 100.0 * _orig->totalSize() ) / (float) _orig->tqparent()->totalSize();
+ _percent = ( 100.0 * _orig->totalSize() ) / (float) _orig->parent()->totalSize();
setText( _view->percentNumCol(), formatPercent ( _percent ) );
}
else
@@ -1367,7 +1367,7 @@ KDirTreeViewItem::cleanupDotEntries()
return;
- // Retqparent dot entry tqchildren if there are no subdirectories on this level
+ // Reparent dot entry tqchildren if there are no subdirectories on this level
if ( ! _orig->firstChild() )
{
@@ -1379,7 +1379,7 @@ KDirTreeViewItem::cleanupDotEntries()
KDirTreeViewItem *nextChild = child->next();
- // Retqparent this child
+ // Reparent this child
// kdDebug() << "Reparenting clone " << child << endl;
dotEntry->removeItem( child );
@@ -1473,8 +1473,8 @@ KDirTreeViewItem::openNotify( bool open )
void
KDirTreeViewItem::openSubtree()
{
- if ( tqparent() )
- tqparent()->setOpen( true );
+ if ( parent() )
+ parent()->setOpen( true );
setOpen( true );
}
@@ -1649,7 +1649,7 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
else
{
/*
- * Call the tqparent's paintCell() method. We don't want to do
+ * Call the parent's paintCell() method. We don't want to do
* all the hassle of drawing strings and pixmaps, regarding
* alignments etc.
*/
diff --git a/kdirstat/kdirtreeview.h b/kdirstat/kdirtreeview.h
index 8e12113..8c9fe8d 100644
--- a/kdirstat/kdirtreeview.h
+++ b/kdirstat/kdirtreeview.h
@@ -12,7 +12,7 @@
#define KDirTreeView_h
-// Alternative tqparent class for KDirTreeView.
+// Alternative parent class for KDirTreeView.
//
// If you change this, don't forget to change the KDirTreeView class
// declaration also. Unfortunately there this 'define' can't be used -
@@ -71,7 +71,7 @@ namespace KDirStat
/**
* Default constructor.
**/
- KDirTreeView( TQWidget * tqparent = 0 );
+ KDirTreeView( TQWidget * parent = 0 );
/**
* Destructor.
@@ -193,7 +193,7 @@ namespace KDirStat
* inevitably be the case for a white background (which unfortunately
* is very common): The percentage bars use white and black for 3D
* borders - like any other widget. But other widgets normally can
- * assume their tqparent widget uses some more neutral color so white and
+ * assume their parent widget uses some more neutral color so white and
* black will result in at least some minimal contrast.
*
* This function automagically sets a reasonable default background
@@ -580,7 +580,7 @@ namespace KDirStat
* Constructor for all other items.
**/
KDirTreeViewItem ( KDirTreeView * view,
- KDirTreeViewItem * tqparent,
+ KDirTreeViewItem * parent,
KFileInfo * orig );
/**
@@ -630,9 +630,9 @@ namespace KDirStat
/**
- * Returns the tqparent view item or 0 if this is the root.
+ * Returns the parent view item or 0 if this is the root.
**/
- KDirTreeViewItem * tqparent() { return _parent; }
+ KDirTreeViewItem * parent() { return _parent; }
/**
* Returns the corresponding original item of the "real" (vs. view)
@@ -721,7 +721,7 @@ namespace KDirStat
/**
* Remove dot entry if it doesn't have any tqchildren.
- * Retqparent all of the dot entry's tqchildren if there are no
+ * Reparent all of the dot entry's tqchildren if there are no
* subdirectories on this level.
**/
void cleanupDotEntries();
@@ -779,7 +779,7 @@ namespace KDirStat
* Initializations common to all constructors.
**/
void init ( KDirTreeView * view,
- KDirTreeViewItem * tqparent,
+ KDirTreeViewItem * parent,
KFileInfo * orig );
protected:
diff --git a/kdirstat/kfeedback.cpp b/kdirstat/kfeedback.cpp
index 0a8a2bf..21e54ff 100644
--- a/kdirstat/kfeedback.cpp
+++ b/kdirstat/kfeedback.cpp
@@ -77,8 +77,8 @@ KFeedbackDialog::checkSendButton()
KFeedbackForm::KFeedbackForm( const TQString & feedbackMailAddress,
- TQWidget * tqparent )
- : TQVBox( tqparent )
+ TQWidget * parent )
+ : TQVBox( parent )
, _feedbackMailAddress( feedbackMailAddress )
{
//
@@ -232,8 +232,8 @@ KFeedbackForm::readyToSend()
-KFeedbackQuestionList::KFeedbackQuestionList( TQWidget *tqparent )
- : TQListView( tqparent )
+KFeedbackQuestionList::KFeedbackQuestionList( TQWidget *parent )
+ : TQListView( parent )
{
addColumn( "" );
header()->hide();
@@ -329,13 +329,13 @@ KFeedbackQuestionList::questionAdded( KFeedbackQuestion * question)
static int nextNo = 0;
-KFeedbackQuestion::KFeedbackQuestion( KFeedbackQuestionList * tqparent,
+KFeedbackQuestion::KFeedbackQuestion( KFeedbackQuestionList * parent,
const TQString & text,
const TQString & id,
bool exclusiveAnswer,
bool required,
bool open )
- : TQCheckListItem( tqparent, text )
+ : TQCheckListItem( parent, text )
, _id( id )
, _exclusiveAnswer( exclusiveAnswer )
, _required( required )
@@ -348,7 +348,7 @@ KFeedbackQuestion::KFeedbackQuestion( KFeedbackQuestionList * tqparent,
setOpen( open );
_no = nextNo++;
- tqparent->questionAdded( this );
+ parent->questionAdded( this );
}
@@ -451,11 +451,11 @@ KFeedbackQuestion::questionList() const
-KFeedbackAnswer::KFeedbackAnswer( KFeedbackQuestion * tqparent,
+KFeedbackAnswer::KFeedbackAnswer( KFeedbackQuestion * parent,
const TQString & text,
const TQString & id,
bool exclusive )
- : TQCheckListItem( tqparent,
+ : TQCheckListItem( parent,
text,
exclusive
? TQCheckListItem::RadioButton
diff --git a/kdirstat/kpacman.cpp b/kdirstat/kpacman.cpp
index ed2090c..22c5176 100644
--- a/kdirstat/kpacman.cpp
+++ b/kdirstat/kpacman.cpp
@@ -200,11 +200,11 @@ KPacManAnimation::animate( TQPainter * painter,
-KPacMan::KPacMan( TQWidget * tqparent,
+KPacMan::KPacMan( TQWidget * parent,
int pacManSize,
bool randomStart,
const char * widgetName )
- : TQWidget( tqparent, widgetName )
+ : TQWidget( parent, widgetName )
{
_pacManSize = pacManSize;
_pacMan = new KPacManAnimation( this, _pacManSize, randomStart );
diff --git a/kdirstat/kpacman.h b/kdirstat/kpacman.h
index e718f10..e088cd5 100644
--- a/kdirstat/kpacman.h
+++ b/kdirstat/kpacman.h
@@ -163,7 +163,7 @@ public:
* @param pacManSize size of the PacMan sprite
* @param randomStart random start position and direction if true
**/
- KPacMan( TQWidget * tqparent = 0,
+ KPacMan( TQWidget * parent = 0,
int pacManSize = 16,
bool randomStart = false,
const char * widgetName = 0 );
diff --git a/kdirstat/kstdcleanup.cpp b/kdirstat/kstdcleanup.cpp
index 903f637..b153e34 100644
--- a/kdirstat/kstdcleanup.cpp
+++ b/kdirstat/kstdcleanup.cpp
@@ -16,12 +16,12 @@ using namespace KDirStat;
KCleanup *
-KStdCleanup::openInKonqueror( KActionCollection *tqparent )
+KStdCleanup::openInKonqueror( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_open_in_konqueror",
"kfmclient openURL %p",
i18n( "Open in &Konqueror" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( true );
@@ -36,12 +36,12 @@ KStdCleanup::openInKonqueror( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::openInTerminal( KActionCollection *tqparent )
+KStdCleanup::openInTerminal( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_open_in_terminal",
"konsole",
i18n( "Open in &Terminal" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( true );
@@ -55,12 +55,12 @@ KStdCleanup::openInTerminal( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::compressSubtree( KActionCollection *tqparent )
+KStdCleanup::compressSubtree( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_compress_subtree",
"cd ..; tar cjvf %n.tar.bz2 %n && rm -rf %n",
i18n( "&Compress" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( false );
@@ -73,12 +73,12 @@ KStdCleanup::compressSubtree( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::makeClean( KActionCollection *tqparent )
+KStdCleanup::makeClean( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_make_clean",
"make clean",
i18n( "&make clean" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( false );
@@ -90,12 +90,12 @@ KStdCleanup::makeClean( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::deleteTrash( KActionCollection *tqparent )
+KStdCleanup::deleteTrash( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_delete_trash",
"rm -f *.o *~ *.bak *.auto core",
i18n( "Delete T&rash Files" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( false );
@@ -108,12 +108,12 @@ KStdCleanup::deleteTrash( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::moveToTrashBin( KActionCollection *tqparent )
+KStdCleanup::moveToTrashBin( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_move_to_trash_bin",
"kfmclient move %p %t",
i18n( "Delete (to Trash &Bin)" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( true );
@@ -127,12 +127,12 @@ KStdCleanup::moveToTrashBin( KActionCollection *tqparent )
KCleanup *
-KStdCleanup::hardDelete( KActionCollection *tqparent )
+KStdCleanup::hardDelete( KActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_hard_delete",
"rm -rf %p",
i18n( "&Delete (no way to undelete!)" ),
- tqparent );
+ parent );
CHECK_PTR( cleanup );
cleanup->setWorksForDir ( true );
cleanup->setWorksForFile ( true );
diff --git a/kdirstat/kstdcleanup.h b/kdirstat/kstdcleanup.h
index a26b1a7..110cd2b 100644
--- a/kdirstat/kstdcleanup.h
+++ b/kdirstat/kstdcleanup.h
@@ -40,13 +40,13 @@ namespace KDirStat
class KStdCleanup
{
public:
- static KCleanup *openInKonqueror ( KActionCollection *tqparent = 0 );
- static KCleanup *openInTerminal ( KActionCollection *tqparent = 0 );
- static KCleanup *compressSubtree ( KActionCollection *tqparent = 0 );
- static KCleanup *makeClean ( KActionCollection *tqparent = 0 );
- static KCleanup *deleteTrash ( KActionCollection *tqparent = 0 );
- static KCleanup *moveToTrashBin ( KActionCollection *tqparent = 0 );
- static KCleanup *hardDelete ( KActionCollection *tqparent = 0 );
+ static KCleanup *openInKonqueror ( KActionCollection *parent = 0 );
+ static KCleanup *openInTerminal ( KActionCollection *parent = 0 );
+ static KCleanup *compressSubtree ( KActionCollection *parent = 0 );
+ static KCleanup *makeClean ( KActionCollection *parent = 0 );
+ static KCleanup *deleteTrash ( KActionCollection *parent = 0 );
+ static KCleanup *moveToTrashBin ( KActionCollection *parent = 0 );
+ static KCleanup *hardDelete ( KActionCollection *parent = 0 );
private:
/**
diff --git a/kdirstat/ktreemaptile.cpp b/kdirstat/ktreemaptile.cpp
index c9af270..5826eb0 100644
--- a/kdirstat/ktreemaptile.cpp
+++ b/kdirstat/ktreemaptile.cpp
@@ -61,7 +61,7 @@ KTreemapTile::KTreemapTile( KTreemapView * parentView,
{
init();
- // Intentionally not copying the tqparent's cushion surface!
+ // Intentionally not copying the parent's cushion surface!
createChildren( rect, orientation );
}
@@ -76,7 +76,7 @@ KTreemapTile::~KTreemapTile()
void
KTreemapTile::init()
{
- // Set up height (z coordinate) - one level higher than the tqparent so this
+ // Set up height (z coordinate) - one level higher than the parent so this
// will be closer to the foreground.
//
// Note that this must happen before any tqchildren are created.
diff --git a/kdirstat/ktreemaptile.h b/kdirstat/ktreemaptile.h
index dc62974..26d8f45 100644
--- a/kdirstat/ktreemaptile.h
+++ b/kdirstat/ktreemaptile.h
@@ -136,7 +136,7 @@ namespace KDirStat
/**
* Constructor: Create a treemap tile from 'fileinfo' that fits into a
- * rectangle 'rect' inside 'tqparent'.
+ * rectangle 'rect' inside 'parent'.
*
* 'orientation' is the direction for further subdivision. 'Auto'
* selects the wider direction inside 'rect'.
@@ -151,7 +151,7 @@ namespace KDirStat
/**
* Alternate constructor: Like the above, but explicitly specify a
- * cushion surface rather than using the tqparent's.
+ * cushion surface rather than using the parent's.
**/
KTreemapTile( KTreemapView * parentView,
KTreemapTile * parentTile,
@@ -174,12 +174,12 @@ namespace KDirStat
KFileInfo * orig() const { return _orig; }
/**
- * Returns the tqparent @ref KTreemapView.
+ * Returns the parent @ref KTreemapView.
**/
KTreemapView * parentView() const { return _parentView; }
/**
- * Returns the tqparent @ref KTreemapTile or 0 if there is none.
+ * Returns the parent @ref KTreemapTile or 0 if there is none.
**/
KTreemapTile * parentTile() const { return _parentTile; }
@@ -224,8 +224,8 @@ namespace KDirStat
* algorithm. For example, tqchildren below a certain size are
* disregarded completely since they will not get an adequate visual
* representation anyway (it would be way too small). They are
- * summarized in some kind of 'misc stuff' area in the tqparent treemap
- * tile - in fact, part of the tqparent directory's tile can be "seen
+ * summarized in some kind of 'misc stuff' area in the parent treemap
+ * tile - in fact, part of the parent directory's tile can be "seen
* through".
*
* In short, a lot of small tqchildren that don't have any useful effect
diff --git a/kdirstat/kcleanup.h b/kdirstat/kcleanup.h
index 28952d9..fedbc00 100644
--- a/kdirstat/kcleanup.h
+++ b/kdirstat/kcleanup.h
@@ -50,13 +50,13 @@ namespace KDirStat
* 'command' is the shell command to execute.
*
* Most applications will want to pass KMainWindow::actionCollection()
* for 'tqparent' so the menus and toolbars can be created using the XML
* UI description ('kdirstatui.rc' for KDirStat).
**/
KCleanup( TQString id = "",
TQString command = "",
TQString title = "",
- KActionCollection * tqparent = 0 );
+ KActionCollection * parent = 0 );
/**
* Copy Constructor.
@@ -182,8 +182,8 @@ namespace KDirStat
* refreshThis: Refresh the KDirTree from the item on that was passed
* to KCleanup::execute().
*
- * refreshParent: Refresh the KDirTree from the tqparent of the item on
- * that was passed to KCleanup::execute(). If there is no such tqparent,
+ * refreshParent: Refresh the KDirTree from the parent of the item on
+ * that was passed to KCleanup::execute(). If there is no such parent,
* refresh the entire tree.
*
* assumeDeleted: Do not actually refresh the KDirTree. Instead,
@@ -50,13 +50,13 @@ namespace KDirStat
*
* Most applications will want to pass KMainWindow::actionCollection()
- * for 'tqparent' so the menus and toolbars can be created using the XML
+ * for 'parent' so the menus and toolbars can be created using the XML
* UI description ('kdirstatui.rc' for KDirStat).
**/
diff --git a/kdirstat/kdirstatapp.h b/kdirstat/kdirstatapp.h
index ea883b7..51e230a 100644
--- a/kdirstat/kdirstatapp.h
+++ b/kdirstat/kdirstatapp.h
@@ -79,7 +79,7 @@ public:
* Construtor of KDirStatApp, calls all init functions to create the
* application.
**/
- KDirStatApp( TQWidget* tqparent=0, const char* name=0 );
+ KDirStatApp( TQWidget* parent=0, const char* name=0 );
/**
* Destructor.
@@ -185,7 +185,7 @@ public slots:
void treemapZoomOut();
/**
* Select the tqparent of the currently selected treemap tile.
**/
void treemapSelectParent();
@@ -185,7 +185,7 @@ public slots:
void treemapZoomOut();
/**
- * Select the tqparent of the currently selected treemap tile.
+ * Select the parent of the currently selected treemap tile.
**/
void treemapSelectParent();
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index 46a1aae..e33a515 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -37,7 +37,7 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
i18n( "Settings" ), // caption
Ok | Apply | Default | Cancel | Help, // buttonMask
Ok, // defaultButton
- 0, // tqparent
+ 0, // parent
0, // name
false ) // modal
, _mainWin( mainWin )
@@ -132,8 +132,8 @@ KSettingsDialog::slotHelp()
KSettingsPage::KSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent )
- : TQWidget( tqparent )
+ TQWidget * parent )
+ : TQWidget( parent )
{
connect( dialog, TQT_SIGNAL( aboutToShow ( void ) ),
this, TQT_SLOT ( setup ( void ) ) );
@@ -159,9 +159,9 @@ KSettingsPage::~KSettingsPage()
KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _treeView( mainWin->treeView() )
, _maxButtons( KDirStatSettingsMaxColorButton )
@@ -274,9 +274,9 @@ KTreeColorsPage::enableColors( int maxColors )
KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _currentCleanup( 0 )
{
@@ -425,8 +425,8 @@ KCleanupPage::storeProps( KCleanup * cleanup )
/*--------------------------------------------------------------------------*/
-KCleanupListBox::KCleanupListBox( TQWidget *tqparent )
- : TQListBox( tqparent )
+KCleanupListBox::KCleanupListBox( TQWidget *parent )
+ : TQListBox( parent )
{
_selection = 0;
@@ -517,9 +517,9 @@ KCleanupListBoxItem::updateTitle()
/*--------------------------------------------------------------------------*/
-KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * tqparent,
+KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
KDirStatApp * mainWin )
- : TQWidget( tqparent )
+ : TQWidget( parent )
, _mainWin( mainWin )
{
TQVBoxLayout *outerBox = new TQVBoxLayout( this, 0, 0 ); // border, spacing
@@ -700,9 +700,9 @@ KCleanupPropertiesPage::fields() const
KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _treeView( mainWin->treeView() )
{
@@ -793,14 +793,14 @@ KGeneralSettingsPage::checkEnabledState()
KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
{
// kdDebug() << k_funcinfo << endl;
- TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // tqparent, border, spacing
+ TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
TQVBox * vbox = new TQVBox( this );
vbox->setSpacing( dialog->spacingHint() );
@@ -890,7 +890,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
label = new TQLabel( i18n( "Minim&um Treemap Tile Size: " ), gridBox );
- _minTileSize = new TQSpinBox( 0, 30, 1, gridBox ); // min, max, step, tqparent
+ _minTileSize = new TQSpinBox( 0, 30, 1, gridBox ); // min, max, step, parent
label->setBuddy( _minTileSize );
grid->addWidget( label, 1, 0 );
@@ -1032,9 +1032,9 @@ KTreemapPage::readColorEntry( KConfig * config, const char * entryName, TQColor
void
-addHStretch( TQWidget * tqparent )
+addHStretch( TQWidget * parent )
{
- TQWidget * stretch = new TQWidget( tqparent );
+ TQWidget * stretch = new TQWidget( parent );
stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
TQSizePolicy::Minimum, // vert
1, // hstretch
@@ -1043,9 +1043,9 @@ addHStretch( TQWidget * tqparent )
void
-addVStretch( TQWidget * tqparent )
+addVStretch( TQWidget * parent )
{
- TQWidget * stretch = new TQWidget( tqparent );
+ TQWidget * stretch = new TQWidget( parent );
stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
TQSizePolicy::Expanding, // vert
0, // hstretch
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index 078860a..f0a5c9e 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -63,8 +63,8 @@ namespace KDirStat
/**
* Constructor.
*
* Notice there is no tqparent widget passed but the application's main
* window so its functions can be accessed. The tqparent of this widget
* is always 0 since this is a dialog.
**/
@@ -90,7 +90,7 @@ namespace KDirStat
* certainly not be the way to go.
*
* This overwritten show() method sends that @ref aboutToShow() signal
* before calling the tqparent class show() method.
**/
virtual void show();
@@ -153,7 +153,7 @@ namespace KDirStat
* e.g., apply(), setup(), revertToDefaults().
**/
KSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent );
+ TQWidget * parent );
/**
* Destructor.
@@ -227,7 +227,7 @@ namespace KDirStat
* Constructor
**/
KTreeColorsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -306,7 +306,7 @@ namespace KDirStat
* Constructor
**/
KCleanupPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -414,7 +414,7 @@ namespace KDirStat
/**
* Constructor.
**/
- KCleanupListBox( TQWidget * tqparent = 0 );
+ KCleanupListBox( TQWidget * parent = 0 );
/**
* Destructor.
@@ -519,7 +519,7 @@ namespace KDirStat
/**
* Constructor
**/
- KCleanupPropertiesPage( TQWidget * tqparent,
+ KCleanupPropertiesPage( TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -579,7 +579,7 @@ namespace KDirStat
* Constructor
**/
KGeneralSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -649,7 +649,7 @@ namespace KDirStat
* Constructor
**/
KTreemapPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -737,12 +737,12 @@ namespace KDirStat
/**
* Add a horizontal stretch widget to take all excess space.
**/
-void addHStretch( TQWidget * tqparent );
+void addHStretch( TQWidget * parent );
/**
* Add a vertical stretch widget to take all excess space.
**/
-void addVStretch( TQWidget * tqparent );
+void addVStretch( TQWidget * parent );
@@ -63,8 +63,8 @@ namespace KDirStat
* Constructor.
*
- * Notice there is no tqparent widget passed but the application's main
- * window so its functions can be accessed. The tqparent of this widget
+ * Notice there is no parent widget passed but the application's main
+ * window so its functions can be accessed. The parent of this widget
* is always 0 since this is a dialog.
**/
@@ -90,7 +90,7 @@ namespace KDirStat
*
* This overwritten show() method sends that @ref aboutToShow() signal
- * before calling the tqparent class show() method.
+ * before calling the parent class show() method.
**/
virtual void show();
diff --git a/kdirstat/kdirtreeiterators.h b/kdirstat/kdirtreeiterators.h
index 248960a..2ab3382 100644
--- a/kdirstat/kdirtreeiterators.h
+++ b/kdirstat/kdirtreeiterators.h
@@ -73,12 +73,12 @@ namespace KDirStat
public:
/**
* Constructor: Initialize an iterator object to iterate over the
* tqchildren of 'tqparent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
*
* Treat the dot entry as if it wasn't there - pretend to move all its
* tqchildren up to the real tqparent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
* tqchildren. Subdirectories will be processed before any file tqchildren.
@@ -89,7 +89,7 @@ namespace KDirStat
* over its tqchildren, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
* its tqchildren (unless, of course, you create an iterator with the dot
* entry as the tqparent).
*
* KDotEntryIgnore:
*
@@ -99,7 +99,7 @@ namespace KDirStat
* tqchildren.
*
**/
- KFileInfoIterator( KFileInfo * tqparent,
+ KFileInfoIterator( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent );
protected:
@@ -107,7 +107,7 @@ namespace KDirStat
* Alternate constructor to be called from derived classes: Those can
* choose not to call next() in the constructor.
**/
- KFileInfoIterator ( KFileInfo * tqparent,
+ KFileInfoIterator ( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy,
bool callNext );
@@ -115,7 +115,7 @@ namespace KDirStat
/**
* Internal initialization called from any constructor.
**/
- void init ( KFileInfo * tqparent,
+ void init ( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy,
bool callNext );
@@ -202,7 +202,7 @@ namespace KDirStat
* Constructor. Specify the sorting order with 'sortOrder' and 'ascending'.
* See @ref KFileInfoIterator for more details.
**/
- KFileInfoSortedIterator( KFileInfo * tqparent,
+ KFileInfoSortedIterator( KFileInfo * parent,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent,
KFileInfoSortOrder sortOrder = KSortByName,
bool ascending = true );
@@ -293,7 +293,7 @@ namespace KDirStat
/**
* Constructor. Children below 'minSize' will be ignored by this iterator.
**/
- KFileInfoSortedBySizeIterator( KFileInfo * tqparent,
+ KFileInfoSortedBySizeIterator( KFileInfo * parent,
KFileSize minSize = 0,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent,
bool ascending = false );
@@ -73,12 +73,12 @@ namespace KDirStat
/**
* Constructor: Initialize an iterator object to iterate over the
- * tqchildren of 'tqparent' (unsorted!), depending on 'dotEntryPolicy':
+ * tqchildren of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
@@ -73,12 +73,12 @@ namespace KDirStat
*
* Treat the dot entry as if it wasn't there - pretend to move all its
- * tqchildren up to the real tqparent. This makes a directory look very
+ * tqchildren up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
@@ -89,7 +89,7 @@ namespace KDirStat
* 'current()' or 'operator*()' will return the dot entry, but none of
* its tqchildren (unless, of course, you create an iterator with the dot
- * entry as the tqparent).
+ * entry as the parent).
*
* KDotEntryIgnore:
diff --git a/kdirstat/kfeedback.h b/kdirstat/kfeedback.h
index 289273b..dc6e59a 100644
--- a/kdirstat/kfeedback.h
+++ b/kdirstat/kfeedback.h
@@ -103,7 +103,7 @@ public:
* Constructor.
**/
KFeedbackForm( const TQString & feedbackMailAddress,
- TQWidget * tqparent );
+ TQWidget * parent );
/**
* Destructor.
@@ -193,7 +193,7 @@ public:
/**
* Constructor.
**/
- KFeedbackQuestionList( TQWidget *tqparent );
+ KFeedbackQuestionList( TQWidget *parent );
/**
* Destructor.
@@ -279,7 +279,7 @@ public:
/**
* Constructor.
*
* The tqparent @ref KFeedbackQuestionList assumes ownership of this object,
* so don't delete it unless you want to delete it from the question list
* as well.
*
@@ -297,7 +297,7 @@ public:
* Set 'exclusiveAnswer' to 'true' if only one of all answers may be
* checked at any one time, to 'false' if multiple answers are allowed.
**/
- KFeedbackQuestion( KFeedbackQuestionList * tqparent,
+ KFeedbackQuestion( KFeedbackQuestionList * parent,
const TQString & text,
const TQString & id,
bool exclusiveAnswer = true,
@@ -371,7 +371,7 @@ public:
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
* the tqparent is no @ref KFeedbackQuestionList.
**/
KFeedbackQuestionList * questionList() const;
@@ -394,7 +394,7 @@ public:
* 'exclusive' tells the type of answer: One of many allowed or any number
* of many.
**/
- KFeedbackAnswer( KFeedbackQuestion * tqparent,
+ KFeedbackAnswer( KFeedbackQuestion * parent,
const TQString & text,
const TQString & id,
bool exclusive = true );
@@ -429,7 +429,7 @@ public:
* Returns the question to this answer.
**/
KFeedbackQuestion * question() const
- { return (KFeedbackQuestion *) TQListViewItem::tqparent(); }
+ { return (KFeedbackQuestion *) TQListViewItem::parent(); }
/**
* Returns the sort key.
@@ -279,7 +279,7 @@ public:
* Constructor.
*
- * The tqparent @ref KFeedbackQuestionList assumes ownership of this object,
+ * The parent @ref KFeedbackQuestionList assumes ownership of this object,
* so don't delete it unless you want to delete it from the question list
* as well.
@@ -371,7 +371,7 @@ public:
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
- * the tqparent is no @ref KFeedbackQuestionList.
+ * the parent is no @ref KFeedbackQuestionList.
**/
KFeedbackQuestionList * questionList() const;
diff --git a/kdirstat/ktreemapview.cpp b/kdirstat/ktreemapview.cpp
index ac4ba6b..03e1f1d 100644
--- a/kdirstat/ktreemapview.cpp
+++ b/kdirstat/ktreemapview.cpp
@@ -29,8 +29,8 @@ using namespace KDirStat;
-KTreemapView::KTreemapView( KDirTree * tree, TQWidget * tqparent, const TQSize & initialSize )
- : TQCanvasView( tqparent )
+KTreemapView::KTreemapView( KDirTree * tree, TQWidget * parent, const TQSize & initialSize )
+ : TQCanvasView( parent )
, _tree( tree )
, _rootTile( 0 )
, _selectedTile( 0 )
@@ -187,7 +187,7 @@ KTreemapView::contentsMousePressEvent( TQMouseEvent * event )
break;
case Qt::MidButton:
// Select clicked tile's tqparent, if available
if ( _selectedTile &&
_selectedTile->rect().contains( event->pos() ) )
@@ -308,8 +308,8 @@ KTreemapView::zoomOut()
{
KFileInfo * root = _rootTile->orig();
- if ( root->tqparent() )
- root = root->tqparent();
+ if ( root->parent() )
+ root = root->parent();
rebuildTreemap( root );
}
@@ -187,7 +187,7 @@ KTreemapView::contentsMousePressEvent( TQMouseEvent * event )
break;
case Qt::MidButton:
- // Select clicked tile's tqparent, if available
+ // Select clicked tile's parent, if available
if ( _selectedTile &&
_selectedTile->rect().contains( event->pos() ) )
diff --git a/kdirstat/ktreemapview.h b/kdirstat/ktreemapview.h
index 5ff3188..29b43c9 100644
--- a/kdirstat/ktreemapview.h
+++ b/kdirstat/ktreemapview.h
@@ -51,7 +51,7 @@ namespace KDirStat
* Constructor.
**/
KTreemapView( KDirTree * tree,
- TQWidget * tqparent = 0,
+ TQWidget * parent = 0,
const TQSize & initialSize = TQSize() );
/**
@@ -128,18 +128,18 @@ namespace KDirStat
void zoomIn();
/**
* Zoom out one level: The tqparent (if there is any) KFileInfo node of
* the current treemap root becomes the new root. This usually works
* only after zoomIn().
**/
void zoomOut();
/**
* Select the tqparent of the currently selected tile (if possible).
*
* This is very much the same as clicking with the middle mouse button,
* but not quite: The middle mouse button cycles back to the tile
* clicked at if there is no more tqparent. This method does not (because
* there is no known mouse position).
**/
void selectParent();
@@ -221,7 +221,7 @@ namespace KDirStat
bool canZoomOut() const;
/**
* Returns true if it is possible to select the tqparent of the currently
* selected tile, false if not.
**/
bool canSelectParent() const;
@@ -128,18 +128,18 @@ namespace KDirStat
void zoomIn();
/**
- * Zoom out one level: The tqparent (if there is any) KFileInfo node of
+ * Zoom out one level: The parent (if there is any) KFileInfo node of
* the current treemap root becomes the new root. This usually works
* only after zoomIn().
@@ -128,18 +128,18 @@ namespace KDirStat
void zoomOut();
/**
- * Select the tqparent of the currently selected tile (if possible).
+ * Select the parent of the currently selected tile (if possible).
*
* This is very much the same as clicking with the middle mouse button,
@@ -128,18 +128,18 @@ namespace KDirStat
* This is very much the same as clicking with the middle mouse button,
* but not quite: The middle mouse button cycles back to the tile
- * clicked at if there is no more tqparent. This method does not (because
+ * clicked at if there is no more parent. This method does not (because
* there is no known mouse position).
**/
@@ -221,7 +221,7 @@ namespace KDirStat
bool canZoomOut() const;
/**
- * Returns true if it is possible to select the tqparent of the currently
+ * Returns true if it is possible to select the parent of the currently
* selected tile, false if not.
**/